﻿param
(
	[switch] $install,
	[switch] $uninstall
)

If ((-Not $install) -And (-Not $uninstall))
{
	Write-Host ""
	Write-Host "DESCRIPTION"
	Write-Host "    This script copies Esri’s JavaScript web content resources to SharePoint for use with Esri Maps for SharePoint"
	Write-Host ""
	Write-Host "SYNTAX"
	Write-Host "    WebContentInstaller.ps1 -install | -uninstall"
	Write-Host ""
	Exit
}

$HiveLocation = ""

If (Test-Path "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0") 
{
	if ((Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0" | %{$_.SharePoint})  -eq "Installed") 
	{
		$HiveLocation = Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0" | %{$_.Location}
	}	
}

if ($HiveLocation -eq "")
{
	If (Test-Path "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0")
    {
	    if ((Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0" | %{$_.SharePoint})  -eq "Installed") 
	    {
			$HiveLocation = Get-ItemProperty "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0" | %{$_.Location}
    	}
    }
}   

if ($HiveLocation -ne "")
{
	$InstallLocation = Join-Path $HiveLocation "TEMPLATE\LAYOUTS\ESRI.ArcGIS.Mapping.SharePoint\scripts"
	
	
	if ($PSScriptRoot -eq $null) 
     {
         $PSScriptRoot = Split-Path $MyInvocation.MyCommand.Path -Parent
     }
		
	$LocalTempPath = Join-Path (Get-Childitem env:LOCALAPPDATA | %{$_.Value}) "Temp"
	
	
	if (Test-Path $InstallLocation)
	{
		Write-Host "Removing the existing JavaScript web content files."		
		CMD /C rmdir "$InstallLocation" /S /Q
		
		
		$ParentDir = Join-Path $HiveLocation "TEMPLATE\LAYOUTS\ESRI.ArcGIS.Mapping.SharePoint"
		$ChildrenItem = Get-Childitem "$ParentDir"		
		if ($ChildrenItem.Count -eq 0)
		{
			CMD /C rmdir "$ParentDir" /S /Q
		}
		
        if ($uninstall) 
        {
            Write-Host "JavaScript web content has been removed successfully."
        }
	} 

	if ($install) 
	{
		$WebContentZipPath = Join-Path $PSScriptRoot "EsriMapsWebContents.zip"
		
		if  (-Not (Test-Path $WebContentZipPath))
		{
			Write-Host "EsriMapsWebContents.zip file cannot be found."
			Exit
		}
		
		
		$TempInstallPath = Join-Path $LocalTempPath "esri_temp"
		if (Test-Path $TempInstallPath)
		{
			CMD /C rmdir "$TempInstallPath" /S /Q
		}
		
		try
		{
			[Reflection.Assembly]::Load("ZipForge, Version=3.0.5.0, Culture=neutral, PublicKeyToken=3a6e82ca8e39718a") | Out-Null
			$Archiver = New-Object ComponentAce.Compression.ZipForge.ZipForge
		}
		catch
		{
			Write-Host "`r`n" $_.Exception.Message
			Exit
		}	
		
		New-Item $TempInstallPath -type directory -force | Out-Null

		Write-Host "`r`nWaiting for the JavaScript web content to install. This may take several minutes.`r`n"
		
		$Archiver.add_OnOverallProgress(
		{	
			param([object]$sender, [double] $percentageDone)
			$done = "{0:P0}" -f ($percentageDone/100.0)
			Write-Host "`r" $done "Done" -NoNewLine
		})		
		
		$Archiver.FileName = $WebContentZipPath
		$Archiver.OpenArchive()
		$Archiver.BaseDir = $TempInstallPath		
		$Archiver.ExtractFiles("*.*")
		$Archiver.CloseArchive()		
		
		
		CMD /C move /Y "$TempInstallPath" "$InstallLocation"

		$diParent = [System.IO.Directory]::GetParent($InstallLocation)
		$ds = $diParent.GetAccessControl()
		$ds.SetAccessRuleProtection($FALSE, $TRUE)
		[System.IO.Directory]::SetAccessControl($InstallLocation, $ds)
		
        Write-Host "`r`nJavaScript web content deployment has completed successfully."
	}		
}
else 
{
	Write-Host "SharePoint is not installed."
}
# SIG # Begin signature block
# MIIX3wYJKoZIhvcNAQcCoIIX0DCCF8wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUz06PLpSufJ5fhINPSKLBvZR1
# jVagghMNMIID7jCCA1egAwIBAgIQfpPr+3zGTlnqS5p31Ab8OzANBgkqhkiG9w0B
# AQUFADCBizELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIG
# A1UEBxMLRHVyYmFudmlsbGUxDzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhh
# d3RlIENlcnRpZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcg
# Q0EwHhcNMTIxMjIxMDAwMDAwWhcNMjAxMjMwMjM1OTU5WjBeMQswCQYDVQQGEwJV
# UzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNVBAMTJ1N5bWFu
# dGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALGss0lUS5ccEgrYJXmRIlcqb9y4JsRDc2vCvy5Q
# WvsUwnaOQwElQ7Sh4kX06Ld7w3TMIte0lAAC903tv7S3RCRrzV9FO9FEzkMScxeC
# i2m0K8uZHqxyGyZNcR+xMd37UWECU6aq9UksBXhFpS+JzueZ5/6M4lc/PcaS3Er4
# ezPkeQr78HWIQZz/xQNRmarXbJ+TaYdlKYOFwmAUxMjJOxTawIHwHw103pIiq8r3
# +3R8J+b3Sht/p8OeLa6K6qbmqicWfWH3mHERvOJQoUvlXfrlDqcsn6plINPYlujI
# fKVOSET/GeJEB5IL12iEgF1qeGRFzWBGflTBE3zFefHJwXECAwEAAaOB+jCB9zAd
# BgNVHQ4EFgQUX5r1blzMzHSa1N197z/b7EyALt0wMgYIKwYBBQUHAQEEJjAkMCIG
# CCsGAQUFBzABhhZodHRwOi8vb2NzcC50aGF3dGUuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwPwYDVR0fBDgwNjA0oDKgMIYuaHR0cDovL2NybC50aGF3dGUuY29tL1Ro
# YXd0ZVRpbWVzdGFtcGluZ0NBLmNybDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
# HQ8BAf8EBAMCAQYwKAYDVR0RBCEwH6QdMBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0y
# MDQ4LTEwDQYJKoZIhvcNAQEFBQADgYEAAwmbj3nvf1kwqu9otfrjCR27T4IGXTdf
# plKfFo3qHJIJRG71betYfDDo+WmNI3MLEm9Hqa45EfgqsZuwGsOO61mWAK3ODE2y
# 0DGmCFwqevzieh1XTKhlGOl5QGIllm7HxzdqgyEIjkHq3dlXPx13SYcqFgZepjhq
# IhKjURmDfrYwggSjMIIDi6ADAgECAhAOz/Q4yP6/NW4E2GqYGxpQMA0GCSqGSIb3
# DQEBBQUAMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMB4XDTEyMTAxODAwMDAwMFoXDTIwMTIyOTIzNTk1OVowYjELMAkGA1UE
# BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTQwMgYDVQQDEytT
# eW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIFNpZ25lciAtIEc0MIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAomMLOUS4uyOnREm7Dv+h8GEKU5Ow
# mNutLA9KxW7/hjxTVQ8VzgQ/K/2plpbZvmF5C1vJTIZ25eBDSyKV7sIrQ8Gf2Gi0
# jkBP7oU4uRHFI/JkWPAVMm9OV6GuiKQC1yoezUvh3WPVF4kyW7BemVqonShQDhfu
# ltthO0VRHc8SVguSR/yrrvZmPUescHLnkudfzRC5xINklBm9JYDh6NIipdC6Anqh
# d5NbZcPuF3S8QYYq3AhMjJKMkS2ed0QfaNaodHfbDlsyi1aLM73ZY8hJnTrFxeoz
# C9Lxoxv0i77Zs1eLO94Ep3oisiSuLsdwxb5OgyYI+wu9qU+ZCOEQKHKqzQIDAQAB
# o4IBVzCCAVMwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAO
# BgNVHQ8BAf8EBAMCB4AwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRw
# Oi8vdHMtb2NzcC53cy5zeW1hbnRlYy5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90
# cy1haWEud3Muc3ltYW50ZWMuY29tL3Rzcy1jYS1nMi5jZXIwPAYDVR0fBDUwMzAx
# oC+gLYYraHR0cDovL3RzLWNybC53cy5zeW1hbnRlYy5jb20vdHNzLWNhLWcyLmNy
# bDAoBgNVHREEITAfpB0wGzEZMBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMjAdBgNV
# HQ4EFgQURsZpow5KFB7VTNpSYxc/Xja8DeYwHwYDVR0jBBgwFoAUX5r1blzMzHSa
# 1N197z/b7EyALt0wDQYJKoZIhvcNAQEFBQADggEBAHg7tJEqAEzwj2IwN3ijhCcH
# bxiy3iXcoNSUA6qGTiWfmkADHN3O43nLIWgG2rYytG2/9CwmYzPkSWRtDebDZw73
# BaQ1bHyJFsbpst+y6d0gxnEPzZV03LZc3r03H0N45ni1zSgEIKOq8UvEiCmRDoDR
# EfzdXHZuT14ORUZBbg2w6jiasTraCXEQ/Bx5tIB7rGn0/Zy2DBYr8X9bCT2bW+IW
# yhOBbQAuOA2oKY8s4bL0WqkBrxWcLC9JG9siu8P+eJRRw4axgohd8D20UaF5Mysu
# e7ncIAkTcetqGVvP6KUwVyyJST+5z3/Jvz4iaGNTmr1pdKzFHTx/kuDDvBzYBHUw
# ggUTMIID+6ADAgECAhArpyFCJIKVAgjZoX6Z4ZjbMA0GCSqGSIb3DQEBCwUAMH8x
# CzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3JhdGlvbjEfMB0G
# A1UECxMWU3ltYW50ZWMgVHJ1c3QgTmV0d29yazEwMC4GA1UEAxMnU3ltYW50ZWMg
# Q2xhc3MgMyBTSEEyNTYgQ29kZSBTaWduaW5nIENBMB4XDTE1MDkwMjAwMDAwMFoX
# DTE4MTAwMTIzNTk1OVowgaUxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpDYWxpZm9y
# bmlhMREwDwYDVQQHEwhSZWRsYW5kczE2MDQGA1UEChQtRW52aXJvbm1lbnRhbCBT
# eXN0ZW1zIFJlc2VhcmNoIEluc3RpdHV0ZSBJbmMuMTYwNAYDVQQDFC1FbnZpcm9u
# bWVudGFsIFN5c3RlbXMgUmVzZWFyY2ggSW5zdGl0dXRlIEluYy4wggEiMA0GCSqG
# SIb3DQEBAQUAA4IBDwAwggEKAoIBAQCu79o2OLpBKir45yGcPzlpYYyp96YgkAFB
# +HY2Ydf4G0F752HvQldWrzoybz9KwVAreGQJVbnRhoyq7tdfW5w+ySm0Hq5hFYSw
# wddWXZSJe/2AUt4fTtK7rdHXgi8s5tSojXUId+vL1xAuGGr4CqJRRpWI5GkjHnir
# PKdhUX07CvCFq4p74kZzbTzlyuLWHzTXA8v8T9hoo3shbT+tr7k9MA5061KvyShA
# oIiz8NvM1279tCkA5gx+766p9YoLUeFa3gOJnqfcSXkbC/T0N8RwFr597ROa/ygN
# SQewsBSu9Divvb4fMeiUn46rBU2sKygzj73RH+Hmyw2sMTymPMHVAgMBAAGjggFi
# MIIBXjAJBgNVHRMEAjAAMA4GA1UdDwEB/wQEAwIHgDArBgNVHR8EJDAiMCCgHqAc
# hhpodHRwOi8vc3Yuc3ltY2IuY29tL3N2LmNybDBmBgNVHSAEXzBdMFsGC2CGSAGG
# +EUBBxcDMEwwIwYIKwYBBQUHAgEWF2h0dHBzOi8vZC5zeW1jYi5jb20vY3BzMCUG
# CCsGAQUFBwICMBkMF2h0dHBzOi8vZC5zeW1jYi5jb20vcnBhMBMGA1UdJQQMMAoG
# CCsGAQUFBwMDMFcGCCsGAQUFBwEBBEswSTAfBggrBgEFBQcwAYYTaHR0cDovL3N2
# LnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL3N2LnN5bWNiLmNvbS9zdi5j
# cnQwHwYDVR0jBBgwFoAUljtT8Hkzl699g+8uK8zKt4YecmYwHQYDVR0OBBYEFIps
# koH1lrei1vnu97UHsrIO5ClcMA0GCSqGSIb3DQEBCwUAA4IBAQAYMcZurVZww8SM
# qcPm8qDspq7OOgMRhm0Owb8r8RjzESq/VH2BGTY6b69TY2yFUco98+Pxc/OylIEb
# oSdM+arDVwqN6dlBm57l1qrIoEKFgUb/kp31CMA4hCEOusrIwOFpBUjhzV1sPRdf
# JEHujRv6OwVtcSl+LVEyDuB/rFjlHLm1O0nCuwsA/Cwgru/CqtusSIXu9YGHRsl3
# ChjxBLjV/5mmdYfivAAEGUUTPguZ6G6uSHRUG35tpVe9XRmN1K43YKBal1No2diq
# YD26L/3WD6GArZmZS66JSxj344aJ9u5BCaJS3v3LaIF0VAmIyCKDbz3pRHPZpHOp
# N7BuliASMIIFWTCCBEGgAwIBAgIQPXjX+XZJYLJhffTwHsqGKjANBgkqhkiG9w0B
# AQsFADCByjELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8w
# HQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTowOAYDVQQLEzEoYykgMjAw
# NiBWZXJpU2lnbiwgSW5jLiAtIEZvciBhdXRob3JpemVkIHVzZSBvbmx5MUUwQwYD
# VQQDEzxWZXJpU2lnbiBDbGFzcyAzIFB1YmxpYyBQcmltYXJ5IENlcnRpZmljYXRp
# b24gQXV0aG9yaXR5IC0gRzUwHhcNMTMxMjEwMDAwMDAwWhcNMjMxMjA5MjM1OTU5
# WjB/MQswCQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24x
# HzAdBgNVBAsTFlN5bWFudGVjIFRydXN0IE5ldHdvcmsxMDAuBgNVBAMTJ1N5bWFu
# dGVjIENsYXNzIDMgU0hBMjU2IENvZGUgU2lnbmluZyBDQTCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBAJeDHgAWryyx0gjE12iTUWAecfbiR7TbWE0jYmq0
# v1obUfejDRh3aLvYNqsvIVDanvPnXydOC8KXyAlwk6naXA1OpA2RoLTsFM6RclQu
# zqPbROlSGz9BPMpK5KrA6DmrU8wh0MzPf5vmwsxYaoIV7j02zxzFlwckjvF7vjEt
# PW7ctZlCn0thlV8ccO4XfduL5WGJeMdoG68ReBqYrsRVR1PZszLWoQ5GQMWXkorR
# U6eZW4U1V9Pqk2JhIArHMHckEU1ig7a6e2iCMe5lyt/51Y2yNdyMK29qclxghJzy
# DJRewFZSAEjM0/ilfd4v1xPkOKiE1Ua4E4bCG53qWjjdm9sCAwEAAaOCAYMwggF/
# MC8GCCsGAQUFBwEBBCMwITAfBggrBgEFBQcwAYYTaHR0cDovL3MyLnN5bWNiLmNv
# bTASBgNVHRMBAf8ECDAGAQH/AgEAMGwGA1UdIARlMGMwYQYLYIZIAYb4RQEHFwMw
# UjAmBggrBgEFBQcCARYaaHR0cDovL3d3dy5zeW1hdXRoLmNvbS9jcHMwKAYIKwYB
# BQUHAgIwHBoaaHR0cDovL3d3dy5zeW1hdXRoLmNvbS9ycGEwMAYDVR0fBCkwJzAl
# oCOgIYYfaHR0cDovL3MxLnN5bWNiLmNvbS9wY2EzLWc1LmNybDAdBgNVHSUEFjAU
# BggrBgEFBQcDAgYIKwYBBQUHAwMwDgYDVR0PAQH/BAQDAgEGMCkGA1UdEQQiMCCk
# HjAcMRowGAYDVQQDExFTeW1hbnRlY1BLSS0xLTU2NzAdBgNVHQ4EFgQUljtT8Hkz
# l699g+8uK8zKt4YecmYwHwYDVR0jBBgwFoAUf9Nlp8Ld7LvwMAnzQzn6Aq8zMTMw
# DQYJKoZIhvcNAQELBQADggEBABOFGh5pqTf3oL2kr34dYVP+nYxeDKZ1HngXI939
# 7BoDVTn7cZXHZVqnjjDSRFph23Bv2iEFwi5zuknx0ZP+XcnNXgPgiZ4/dB7X9ziL
# qdbPuzUvM1ioklbRyE07guZ5hBb8KLCxR/Mdoj7uh9mmf6RWpT+thC4p3ny8qKqj
# PQQB6rqTog5QIikXTIfkOhFf1qQliZsFay+0yQFMJ3sLrBkFIqBgFT/ayftNTI/7
# cmd3/SeUx7o1DohJ/o39KK9KEr0Ns5cF3kQMFfo2KwPcwVAB8aERXRTl4r0nS1S+
# K4ReD6bDdAUK75fDiSKxH3fzvc1D1PFMqT+1i4SvZPLQFCExggQ8MIIEOAIBATCB
# kzB/MQswCQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24x
# HzAdBgNVBAsTFlN5bWFudGVjIFRydXN0IE5ldHdvcmsxMDAuBgNVBAMTJ1N5bWFu
# dGVjIENsYXNzIDMgU0hBMjU2IENvZGUgU2lnbmluZyBDQQIQK6chQiSClQII2aF+
# meGY2zAJBgUrDgMCGgUAoHAwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwIwYJ
# KoZIhvcNAQkEMRYEFKaQQye9V4IQcFT1obUCI4/GupyKMA0GCSqGSIb3DQEBAQUA
# BIIBAIFdP23zUg1abPhuArN0gO6qOXUtXJuSdUTbszIDF254A/Yenz5funVZRf5S
# loTTsKAmNfF1r/11b+tBc5qSJ4Y+PNZ/IN5uT3fzuZp0mYHRyPaT1xs/YRpESNv8
# Pt0y8tz/E2SeOJ4A9j4NBz0AvIjHNe41gKVr+4btBY+bUCDlQ6rwPGi0Cli889NY
# Q2nRW9Uo42Rqk2jWCVMbzaf8O7rxMNymIHRvWrDAgZobW1NHwLLF6+Y0vwtiQiZz
# 3vZs8RaWlnFGvgg/hoDGc2dkaZRS4VPGLKz0WE9iExHaQ3JAEWVTPvGKx1xm63ym
# 7fxUGA/FVTOToXHuG+mNmk41zLehggILMIICBwYJKoZIhvcNAQkGMYIB+DCCAfQC
# AQEwcjBeMQswCQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRp
# b24xMDAuBgNVBAMTJ1N5bWFudGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0Eg
# LSBHMgIQDs/0OMj+vzVuBNhqmBsaUDAJBgUrDgMCGgUAoF0wGAYJKoZIhvcNAQkD
# MQsGCSqGSIb3DQEHATAcBgkqhkiG9w0BCQUxDxcNMTUxMDIzMTgxODQ2WjAjBgkq
# hkiG9w0BCQQxFgQURf0uB30QrYcl4Ne6hMMwms693TYwDQYJKoZIhvcNAQEBBQAE
# ggEAbUh1l/OUQl6CZLE5oGdwXklJWOxr2dzOaLXCBowjAfJUgpmakkBlIvMwLXQw
# 3VPmUB7t0PfBEJetrFZdSmlInRaqDWSyLbX1TV6W6c/1Tx1rQwvdE7x33yXCyaW1
# fHmX4YczOdd6F71B+LpZYOcuOWrl8yh665Coth/FOqY2BLRtDhsFJk/JHs6MTkTp
# tHIoXbRe2psO9kSrI0OBgFow/vU7REdingclnoFkZaYk1YYiISSvdnNDpn0zcDV2
# gwE71W9peBnye2HdptieWXTezLV2CtM2uYFFhFrJNfcs5i+gXpv9PEuHHf7iP4eP
# 5wCM78ZvLlkKxQXMR32fFaRf/Q==
# SIG # End signature block
